Module node_bindgen::core::log
source · Modules
UNSTABLE: Structured key-value pairs.
Macros
Get a value from a type implementing
std::fmt::Debug.Get a value from a type implementing
std::fmt::Display.Logs a message at the debug level.
Logs a message at the error level.
Logs a message at the info level.
The standard logging macro.
Determines if a message logged at the specified level in that module will
be logged.
Logs a message at the trace level.
Logs a message at the warn level.
Structs
Metadata about a log message.
Builder for
Metadata.The type returned by
from_str when the string doesn’t match any of the log levels.The “payload” of a log message.
Builder for
Record.The type returned by
set_logger if set_logger has already been called.Enums
An enum representing the available verbosity levels of the logger.
An enum representing the available verbosity level filters of the logger.
Constants
The statically resolved maximum log level.
Traits
A trait encapsulating the operations required of a logger.
Functions
Returns a reference to the logger.
Returns the current maximum log level.
Sets the global logger to a
Box<Log>.Sets the global logger to a
&'static Log.A thread-unsafe version of
set_logger.Sets the global maximum log level.