Struct node_bindgen::core::ThreadSafeFunction
source · pub struct ThreadSafeFunction { /* private fields */ }Expand description
Wrapper for thread safe function that are safe to send and sync across thread
pub struct ThreadSafeFunction { /* private fields */ }Wrapper for thread safe function that are safe to send and sync across thread